[Bedework-commit] rpiutil r76 - trunk/src/edu/rpi/sss/util/servlets

svnadmin at bedework.org svnadmin at bedework.org
Tue Apr 1 10:42:27 EDT 2008


Author: douglm
Date: 2008-04-01 10:42:27 -0400 (Tue, 01 Apr 2008)
New Revision: 76

Modified:
   trunk/src/edu/rpi/sss/util/servlets/ConfiguredXSLTFilter.java
Log:
Use StringBuilder instead of StringBuffer

Modified: trunk/src/edu/rpi/sss/util/servlets/ConfiguredXSLTFilter.java
===================================================================
--- trunk/src/edu/rpi/sss/util/servlets/ConfiguredXSLTFilter.java	2008-03-25 02:55:00 UTC (rev 75)
+++ trunk/src/edu/rpi/sss/util/servlets/ConfiguredXSLTFilter.java	2008-04-01 14:42:27 UTC (rev 76)
@@ -380,7 +380,7 @@
      * Then set the ideal and actual paths ready for the transform.
      */
 
-    StringBuffer idealPath = new StringBuffer(xcfg.cfg.getAppRoot());
+    StringBuilder idealPath = new StringBuilder(xcfg.cfg.getAppRoot());
 
     idealPath.append("/");
     idealPath.append(xcfg.cfg.getLocaleInfo());
@@ -400,7 +400,7 @@
        * try, locale, browser type and skin name.
        */
 
-      StringBuffer xsltPath = new StringBuffer(xcfg.cfg.getAppRoot());
+      StringBuilder xsltPath = new StringBuilder(xcfg.cfg.getAppRoot());
 
       /* ============== Locale ================= */
 
@@ -534,12 +534,12 @@
 
   /** Try a path and see if it exists. If so append the element
    *
    * @param   prefix    StringBuffer current path prefix
    * @param   el        String path element to append
    * @param   dir       true if el is a directory
    * @return  boolean   true if path is OK
    */
-  private boolean tryPath(StringBuffer prefix, String el, boolean dir) {
+  private boolean tryPath(StringBuilder prefix, String el, boolean dir) {
     String path = prefix + "/" + el;
 
     if (dir && directoryBrowsingDisallowed) {
@@ -534,12 +534,12 @@
   /** Try a path and see if it exists. If so append the element
    *
-   * @param   prefix    StringBuffer current path prefix
+   * @param   prefix    StringBuilder current path prefix
    * @param   el        String path element to append
    * @param   dir       true if el is a directory



More information about the Bedework-commit mailing list